@@ -20,20 +20,30 @@
  *
  */
 
+
 #include <Rcpp.h>
 #include "binomial_heap.hpp"
 
+
 RCPP_MODULE(binomial_heap_module) {
     Rcpp::class_< binomial_heap_ss >( "binomial_heap_ss" )
-    .constructor()
-    .method("peek",   &binomial_heap_ss::peek)
-    .method("pop",    &binomial_heap_ss::pop)
-    .method("size",   &binomial_heap_ss::size)
-    .method("insert", &binomial_heap_ss::insert)
-    .method("clear",  &binomial_heap_ss::clear);
+        .constructor()
+        .method("peek",   &binomial_heap_ss::peek)
+        .method("handles",   &binomial_heap_ss::handles)
+        .method("handles_value",   &binomial_heap_ss::handles_value)
+        .method("values",   &binomial_heap_ss::values)
+        .method("decrease_key",   &binomial_heap_ss::decrease_key)
+        .method("pop",    &binomial_heap_ss::pop)
+        .method("size",   &binomial_heap_ss::size)
+        .method("insert", &binomial_heap_ss::insert)
+        .method("clear",  &binomial_heap_ss::clear);
     Rcpp::class_< binomial_heap_sd >( "binomial_heap_sd" )
         .constructor()
         .method("peek",   &binomial_heap_sd::peek)
+        .method("handles",   &binomial_heap_sd::handles)
+        .method("handles_value",   &binomial_heap_sd::handles_value)
+        .method("values",   &binomial_heap_sd::values)
+        .method("decrease_key",   &binomial_heap_sd::decrease_key)
         .method("pop",    &binomial_heap_sd::pop)
         .method("size",   &binomial_heap_sd::size)
         .method("insert", &binomial_heap_sd::insert)
@@ -41,14 +51,21 @@ RCPP_MODULE(binomial_heap_module) {
     Rcpp::class_< binomial_heap_si >( "binomial_heap_si" )
         .constructor()
         .method("peek",   &binomial_heap_si::peek)
+        .method("handles",   &binomial_heap_si::handles)
+        .method("handles_value",   &binomial_heap_si::handles_value)
+        .method("values",   &binomial_heap_si::values)
+        .method("decrease_key",   &binomial_heap_si::decrease_key)
         .method("pop",    &binomial_heap_si::pop)
         .method("size",   &binomial_heap_si::size)
         .method("insert", &binomial_heap_si::insert)
         .method("clear",  &binomial_heap_si::clear);
-
     Rcpp::class_< binomial_heap_dd >( "binomial_heap_dd" )
         .constructor()
         .method("peek",   &binomial_heap_dd::peek)
+        .method("handles",   &binomial_heap_dd::handles)
+        .method("handles_value",   &binomial_heap_dd::handles_value)
+        .method("values",   &binomial_heap_dd::values)
+        .method("decrease_key",   &binomial_heap_dd::decrease_key)
         .method("pop",    &binomial_heap_dd::pop)
         .method("size",   &binomial_heap_dd::size)
         .method("insert", &binomial_heap_dd::insert)
@@ -56,6 +73,10 @@ RCPP_MODULE(binomial_heap_module) {
     Rcpp::class_< binomial_heap_ds >( "binomial_heap_ds" )
         .constructor()
         .method("peek",   &binomial_heap_ds::peek)
+        .method("handles",   &binomial_heap_ds::handles)
+        .method("handles_value",   &binomial_heap_ds::handles_value)
+        .method("values",   &binomial_heap_ds::values)
+        .method("decrease_key",   &binomial_heap_ds::decrease_key)
         .method("pop",    &binomial_heap_ds::pop)
         .method("size",   &binomial_heap_ds::size)
         .method("insert", &binomial_heap_ds::insert)
@@ -63,6 +84,10 @@ RCPP_MODULE(binomial_heap_module) {
     Rcpp::class_< binomial_heap_di >( "binomial_heap_di" )
         .constructor()
         .method("peek",   &binomial_heap_di::peek)
+        .method("handles",   &binomial_heap_di::handles)
+        .method("handles_value",   &binomial_heap_di::handles_value)
+        .method("values",   &binomial_heap_di::values)
+        .method("decrease_key",   &binomial_heap_di::decrease_key)
         .method("pop",    &binomial_heap_di::pop)
         .method("size",   &binomial_heap_di::size)
         .method("insert", &binomial_heap_di::insert)
@@ -70,6 +95,10 @@ RCPP_MODULE(binomial_heap_module) {
     Rcpp::class_< binomial_heap_id >( "binomial_heap_id" )
         .constructor()
         .method("peek",   &binomial_heap_id::peek)
+        .method("handles",   &binomial_heap_id::handles)
+        .method("handles_value",   &binomial_heap_id::handles_value)
+        .method("values",   &binomial_heap_id::values)
+        .method("decrease_key",   &binomial_heap_id::decrease_key)
         .method("pop",    &binomial_heap_id::pop)
         .method("size",   &binomial_heap_id::size)
         .method("insert", &binomial_heap_id::insert)
@@ -77,6 +106,10 @@ RCPP_MODULE(binomial_heap_module) {
     Rcpp::class_< binomial_heap_is >( "binomial_heap_is" )
         .constructor()
         .method("peek",   &binomial_heap_is::peek)
+        .method("handles",   &binomial_heap_is::handles)
+        .method("handles_value",   &binomial_heap_is::handles_value)
+        .method("values",   &binomial_heap_is::values)
+        .method("decrease_key",   &binomial_heap_is::decrease_key)
         .method("pop",    &binomial_heap_is::pop)
         .method("size",   &binomial_heap_is::size)
         .method("insert", &binomial_heap_is::insert)
@@ -84,6 +117,10 @@ RCPP_MODULE(binomial_heap_module) {
     Rcpp::class_< binomial_heap_ii >( "binomial_heap_ii" )
         .constructor()
         .method("peek",   &binomial_heap_ii::peek)
+        .method("handles",   &binomial_heap_ii::handles)
+        .method("handles_value",   &binomial_heap_ii::handles_value)
+        .method("values",   &binomial_heap_ii::values)
+        .method("decrease_key",   &binomial_heap_ii::decrease_key)
         .method("pop",    &binomial_heap_ii::pop)
         .method("size",   &binomial_heap_ii::size)
         .method("insert", &binomial_heap_ii::insert)
